#!/bin/sh
# *******************************************************************************
#  Materiales bajo licencia - Propiedad de IBM
#  (c) Copyright IBM Corporation 2011. Reservados todos los derechos.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# Archivo de los mensajes que muestran los scripts automáticos de actualización.
#
# ################################################################################


# *********************
# * Función de mensajes *
# *********************
messages() {

case $1 in

# ************************************
# * Mensajes de verificación inicial *
# ************************************

INVALID_LAUNCH )
echo ""
echo "No ejecute el script app_upgrade directamente.  Para actualizar JTS o la aplicación, ejecute uno de los siguientes mandatos:"
echo "    ccm_upgrade"
echo "    jts_upgrade"
echo "    qm_upgrade"
echo "    rm_upgrade"
echo "Utilice -help para obtener una descripción completa de los mandatos de arriba."
;;

INVALID_START_DIR )
echo ""
echo "Salvo cuando se utiliza el parámetro -help, el script $2 no se puede ejecutar desde ningún directorio que no sea $3"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "El archivo '$2' contiene los valores de parámetro del script de actualización."
echo "Si necesita modificar alguno de los valores de parámetro predeterminados, puede editar estos archivos o puede especificar los valores de parámetro como argumentos de línea de mandatos en los scripts de actualización."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "El siguiente conjunto de archivos contiene valores de parámetro predeterminados para un aplicación o actualización de JTS.  Si necesita modificar alguno de los valores de parámetro predeterminados, puede editar estos archivos o puede especificar los valores de parámetro como argumentos de línea de mandatos en los scripts de actualización."
echo "- Actualización de CCM: $2/params/ccm_params$3.sh"
echo "- Actualización de QM:  $2/params/qm_params$3.sh"
echo "- Actualización de RM:  $2/params/rm_params$3.sh"
echo "- Actualización de JTS: $2/params/jts_params$3.sh"
echo ""
;;


# ************************************
# * Mensajes de verificación de parámetros *
# ************************************

# Verificación intrínseca
# ======================

MISSING_APP_TYPE )
echo ""
echo "No se ha especificado JTS ni ningún tipo de aplicación.  Para actualizar JTS o la aplicación, ejecute uno de los siguientes mandatos:"
echo "    ccm_upgrade"
echo "    jts_upgrade"
echo "    qm_upgrade"
echo "    rm_upgrade"
echo "Utilice -help para obtener una descripción completa de los mandatos de arriba."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 no es un JTS o un tipo de aplicación válido.  Para actualizar JTS o la aplicación, ejecute uno de los siguientes mandatos:"
echo "    ccm_upgrade"
echo "    jts_upgrade"
echo "    qm_upgrade"
echo "    rm_upgrade"
echo "Utilice -help para obtener una descripción completa de los mandatos de arriba."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Falta un valor para el parámetro $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "El directorio $3 especificado para el parámetro $2 no existe o no es válido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "El directorio $3 especificado para el parámetro $2 debe ser una vía de acceso absoluta."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "El archivo $3 especificado para el parámetro $2 no existe o no es válido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 es un valor no válido para el parámetro $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 es un parámetro desconocido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;


# Verificación extrínseca
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Falta el parámetro $2 del directorio de inicio."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "El directorio $2 no existe o no es válido."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "No se puede encontrar el mandato repotools de aplicación '$2'."
echo ""
echo "Compruebe que el parámetro oldApplicationHome '$3' señala al directorio de configuración del servidor antiguo; por ejemplo, 'JazzInstallRoot/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parámetro -oldApplicationHome '$3' señala al antiguo directorio de configuración del servidor; por ejemplo, 'JazzInstallRoot/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro oldApplicationHome '$3' señala al directorio de configuración del servidor antiguo; por ejemplo, 'JazzInstallRoot/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro -oldApplicationHome '$3' señala al antiguo directorio de configuración del servidor; por ejemplo, 'JazzInstallRoot/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parámetro -newApplicationHome '$3' señala al nuevo directorio de configuración del servidor; por ejemplo, 'JazzInstallRoot/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo "Si va a realizar una actualización desde un release anterior, asegúrese de que ha seleccionado las raíces de contexto correctas.  Por ejemplo, si utiliza Gestor de instalación, debe seleccionar la opción de raíz de contexto $5 en el panel 'Opciones de raíz de contexto'. Si ha seleccionado por accidente una opción diferente, debe volver a instalar el producto con la opción de raíz de contexto $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro -newApplicationHome '$3' señala al nuevo directorio de configuración del servidor JTS; por ejemplo, 'JazzInstallRoot/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo "Si va a realizar una actualización desde un release anterior, asegúrese de que ha seleccionado las raíces de contexto correctas.  Por ejemplo, si utiliza Gestor de instalación, debe seleccionar la opción de raíz de contexto $5 en el panel 'Opciones de raíz de contexto'. Si ha seleccionado por accidente una opción diferente, debe volver a instalar el producto con la opción de raíz de contexto $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parámetro oldJTSHome '$3' señala al antiguo directorio de configuración del servidor de JTS; por ejemplo, 'JazzInstallRoot/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro oldJTSHome '$3' señala al antiguo directorio de configuración del servidor de JTS; por ejemplo, 'JazzInstallRoot/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Compruebe que el parámetro -newJTSHome '$3' señala al nuevo directorio de configuración del servidor JTS; por ejemplo, 'JazzInstallRoot/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Compruebe que el parámetro -newJTSHome '$3' señala al nuevo directorio de configuración del servidor JTS; por ejemplo, 'JazzInstallRoot/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Falta el archivo tar que contiene los datos de la versión 2.x necesarios para actualizar $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;


# **********************
# * Mensajes de ejecución *
# **********************

BANNER_jts )
echo ""
echo ""
echo "=============================================="
echo "=== Actualización de JTS de $2 a 3.0.1.2  ==="
echo "=============================================="
echo ""
;;

BANNER_ccm )
echo ""
echo ""
echo "=============================================="
echo "=== Actualización de CCM de $2 a 3.0.1.2  ==="
echo "=============================================="
echo ""
;;

BANNER_qm )
echo ""
echo ""
echo "============================================="
echo "=== Actualización de QM de $2 a 3.0.1.2  ==="
echo "============================================="
echo ""
;;

BANNER_rm )
echo ""
echo ""
echo "============================================="
echo "=== Actualización de RM de $2 a 3.0.1.2  ==="
echo "============================================="
echo ""
;;


# *********************
# * Conmutar primer paso *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "La última ejecución falló en el paso inicial..."
;;

LAST_STEP_FAILED )
echo ""
echo "La última ejecución falló en el paso $2..."
echo "¿Desea reiniciar la actualización desde este paso o desde otro anterior?"
;;

ALREADY_RUN )
echo ""
echo "La actualización se ha realizado y ha finalizado satisfactoriamente..."
echo "¿Desea iniciar una nueva a partir de un determinado paso?"
;;

LAST_STEP_PASSED )
echo ""
echo "La última ejecución se detuvo satisfactoriamente en el paso $2..."
echo "¿Desea reiniciar la actualización desde el paso $3 actual o desde otro anterior?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Especifique el número de paso [$2-$3] desde el que desee reiniciar la actualización o pulse la tecla [Intro] para cancelar:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' no es un número. Especifique un número de paso válido."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' no es un número de paso válido. Especifique un número de paso válido."
;;

MAX_STEP_NUMBER )
echo ""
echo "El último paso es $2; por lo tanto, no podrá reiniciar la actualización en el paso $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "El paso $2 no se ha ejecutado todavía; por lo tanto, no podrá reiniciar la actualización en el paso $3."
;;


# **********************
# * Mensajes de pasos  *
# **********************

STEP_0_IBMi )
echo "Paso 0: descartar tablas"
echo "------------------------"
;;

STEP_0 )
echo "Paso 0: Actualizar archivos de configuración"
echo "--------------------------------------------"
;;

STEP_1_ADD )
echo "Paso 1: Añadir tablas"
echo "---------------------"
;;

STEP_1_IMPORT )
echo "Paso 1: Importar datos de $2"
echo "--------------------------------------"
;;

STEP_2_EXPORT_USER_INFO )
echo "Paso 2: Exportar información de usuario desde la base de datos de aplicación"
echo "----------------------------------------------------------------------------"
;;

STEP_2_COPY_TEXT_INDICES )
echo "Paso 2: Copiar índices de texto"
echo "-------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Paso 2: Actualizar esquema de almacén de datos"
echo "----------------------------------------------"
;;

STEP_3_IMPORT_USER_INFO )
echo "Paso 3: Importar información de usuario en la base de datos JTS"
echo "---------------------------------------------------------------"
;;

STEP_3_UPGRADE_DATA_WAREHOUSE )
echo "Paso 3: Actualizar esquema de almacén de datos"
echo "----------------------------------------------"
;;

STEP_4 )
echo "Paso 4: Importar información de usuario JTS en la base de datos de aplicación"
echo "-----------------------------------------------------------------------------"
;;

STEP_5 )
echo "Paso $2: Reconstruir índices de texto"
echo "------------------------------------"
;;

STEP_6 )
echo "Paso $2: Recrear índices de búsqueda y consulta"
echo "----------------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "La actualización $2 falló en el paso $3.  Corrija el problema y vuelva a ejecutar el script comenzando por el paso $3."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_JTS )
echo ""
echo "La actualización $2 ha sido satisfactoria.  Inicie el servidor y utilice el asistente de configuración de JTS para validar la configuración JTS.  Ahora podrá también actualizar las aplicaciones en su entorno."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_RM )
echo ""
echo "La parte fuera de línea de la actualización $2 ha sido satisfactoria.  Inicie el servidor y vaya hasta el asistente de migración $2 para completar la migración en línea."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_CCM_QM )
echo ""
echo "La actualización $2 ha sido satisfactoria. Inicie los servidores en el despliegue. Si el JTS no se ha configurado, utilice el asistente de configuración para configurarlo y registrar la aplicación. De lo contrario, registre la aplicación en la página de administración de servidores de JTS."
echo ""
;;

# *****************************************
# * Mensajes mientras se ejecuta un paso  *
# *****************************************

STEP_DIR_CMD )
echo ""
echo "Directorio: $2"
echo "Mandato:"
;;

ENTER_STEP_ACTION )
echo "Especifique [E] para ejecutar este paso, [S] para omitirlo o pulse [Intro] para cancelar la ejecución del script:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' no es una entrada válida; solo se permiten 'E', 'S' o 'Intro'"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Se abrirá un editor vi para permitirle verificar el archivo teamserver.properties de $2."
echo "Verifique que la raíz del URI público indicada por la propiedad com.ibm.team.repository.server.webapp.url es correcta."
echo "Verifique que las propiedades de la base de datos son correctas."
echo "Cuando haya finalizado, guarde los cambios, si hay alguno, y cierre el editor para continuar ejecutando el script."
echo ""
echo "Consulte el tema 'Upgrading the Jazz Team Server and the CLM applications' en el centro de información"
echo "para obtener información sobre cómo configurar adecuadamente cada propiedad:"
echo
;;

PAUSE )
echo ""
echo "Escriba [C] para proseguir la ejecución o pulse [Intro] para cancelar la ejecución del script:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' no es una entrada válida; solo se permiten 'C' o 'Intro'"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "No se han podido copiar los índices de texto de '$2' a '$3'."
echo "Verifique la propiedad com.ibm.team.fulltext.indexLocation"
echo "definida en el archivo teamserver.properties."
echo "Copie manualmente los índices de texto en este directorio"
echo "o ejecute repotools -rebuildTextIndices para reconstruirlos."
echo ""
;;

# *****************************************
# * Mensajes de verificación de URI públicos *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "No hay ningún URI público definido en"
echo "$3,"
echo "por lo que no se puede iniciar la actualización."
echo ""
echo "Debe haber un URI público en este archivo definido del siguiente modo:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propiedad del URI público com.ibm.team.repository.server.webapp.url debe estar presente en el archivo teamserver.properties."
echo "Añada la propiedad al archivo 2.x teamserver.properties y defina el valor para que sea la raíz del URI que todos los clientes utilizan para alcanzar el servidor."
echo "La raíz del URI público es fundamental para el apropiado funcionamiento de su servidor 3.0.1.x. La actualización no se realizará correctamente sin esta propiedad."
echo "Para obtener más, consulte el tema 'Planning your URIs' del centro de información en:"
echo "http://publib.boulder.ibm.com/infocenter/clmhelp/v3r0m1/topic/com.ibm.jazz.install.doc/topics/c_planning_URLs.html"
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Todos los URI públicos definidos en"
echo "$3,"
echo "se han comentado, por lo tanto, no se puede iniciar la actualización."
echo ""
echo "Debe haber un URI público sin comentar en este archivo definido del siguiente modo:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propiedad del URI público com.ibm.team.repository.server.webapp.url debe estar presente en el archivo teamserver.properties."
echo "Añada la propiedad al archivo 2.x teamserver.properties y defina el valor para que sea la raíz del URI que todos los clientes utilizan para alcanzar el servidor."
echo "La raíz del URI público es fundamental para el apropiado funcionamiento de su servidor 3.0.1.x. La actualización no se realizará correctamente sin esta propiedad."
echo "Para obtener más, consulte el tema 'Planning your URIs' del centro de información en:"
echo "http://publib.boulder.ibm.com/infocenter/clmhelp/v3r0m1/topic/com.ibm.jazz.install.doc/topics/c_planning_URLs.html"
echo ""
;;

esac

}
