#!/bin/sh
# *******************************************************************************
#  Materiais Licenciados - Propriedade da IBM
#  (c) Copyright IBM Corporation 2011. Todos os Direitos Reservados.
#
#  Nota sobre Direitos Restritos para Usuários do Governo dos Estados Unidos:
#  Uso, duplicação ou divulgação restritos pelo documento GSA ADP Schedule
#  Contract com a IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# Arquivo para mensagens exibido pelos scripts automatizados de upgrade.
#
# ################################################################################


# *********************
# * Função de Mensagens *
# *********************
messages() {

case $1 in 

# *********************************
# * Mensagens de verificação inicial *
# *********************************

INVALID_LAUNCH )
echo ""
echo "Não execute o script app_upgrade diretamente. Para fazer upgrade do JTS ou do aplicativo, execute um dos seguintes comandos:"
echo "    ccm_upgrade"
echo "    jts_upgrade"
echo "    qm_upgrade"
echo "    rm_upgrade"
echo "Use -help para obter uma descrição completa dos comandos acima."
;;

INVALID_START_DIR )
echo ""
echo "Exceto ao usar o parâmetro -help, o script $2 não pode ser executado a partir de um outro diretório diferente de $3"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "O arquivo '$2' contém os valores de parâmetro para script de atualização."
echo "Se precisar modificar qualquer valor de parâmetro padrão, é possível editar estes arquivos ou especificar os valores de parâmetro como argumentos de linha de comandos para os scripts de atualização."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "O seguinte conjunto de arquivos contém valores de parâmetro padrão para um aplicativo ou atualização de JTS.  Se for necessário modificar qualquer valor de parâmetro padrão, é possível editar estes arquivos ou especificar os valores de parâmetro como argumentos de linha de comandos para os scripts de atualização."
echo "- Atualização do CCM: $2/params/ccm_params$3.sh"
echo "- Atualização do QM:  $2/params/qm_params$3.sh"
echo "- Atualização do RM:  $2/params/rm_params$3.sh"
echo "- Atualização do JTS: $2/params/jts_params$3.sh"
echo ""
;;


# ************************************
# * Mensagens de verificação de parâmetros *
# ************************************

# Verificação Intrínseca
# ======================

MISSING_APP_TYPE )
echo ""
echo "Nenhum JTS ou tipo de aplicativo foi especificado.  Para fazer upgrade do JTS ou do aplicativo, execute um dos seguintes comandos:"
echo "    ccm_upgrade"
echo "    jts_upgrade"
echo "    qm_upgrade"
echo "    rm_upgrade"
echo "Use -help para obter uma descrição completa dos comandos acima."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 não é um JTS ou tipo de aplicativo válido.  Para fazer upgrade do JTS ou do aplicativo, execute um dos seguintes comandos:"
echo "    ccm_upgrade"
echo "    jts_upgrade"
echo "    qm_upgrade"
echo "    rm_upgrade"
echo "Use -help para obter uma descrição completa dos comandos acima."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Valor ausente para o parâmetro $2."
echo "Use -help para obter uma descrição completa dos parâmetros."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "O diretório $3, especificado para o parâmetro $2, não existe ou não é válido."
echo "Use -help para obter uma descrição completa dos parâmetros."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "O diretório $3 especificado para o parâmetro $2 deve ser uma caminho absoluto."
echo "Use -help para obter uma descrição completa dos parâmetros."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "O arquivo $3, especificado para o parâmetro $2, não existe ou não é válido."
echo "Use -help para obter uma descrição completa dos parâmetros."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 é um valor inválido para o parâmetro $2."
echo "Use -help para obter uma descrição completa dos parâmetros."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 é um parâmetro desconhecido."
echo "Use -help para obter uma descrição completa dos parâmetros."
echo ""
;;


# Verificação Extrínseca
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Parâmetro $2 do diretório inicial ausente."
echo "Use -help para obter uma descrição completa dos parâmetros."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "O diretório $2 não existe ou não é válido."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "Não é possível localizar o comando repotools do aplicativo '$2'."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o diretório de configuração do servidor antigo, por exemplo, 'JazzInstallRoot/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "Não é possível localizar o comando repotools do aplicativo '$2'."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o diretório de configuração do servidor antigo, por exemplo, 'JazzInstallRoot/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o diretório de configuração do servidor antigo, por exemplo, 'JazzInstallRoot/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o diretório de configuração do servidor antigo, por exemplo, 'JazzInstallRoot/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "Não é possível localizar o comando repotools do aplicativo '$2'."
echo ""
echo "Verifique se o parâmetro -newApplicationHome '$3' está apontando para o novo diretório de configuração do servidor de aplicativos, por exemplo, 'JazzInstallRoot/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo "Se você estiver fazendo upgrade de uma liberação anterior, assegure-se de que tenha selecionado as raízes de contexto corretas.  Por exemplo, se estiver usando o Installation Manager, você deverá selecionar a opção de raiz de contexto $5 no painel "Opções de Raiz de Contexto".  Se tiver selecionado, acidentalmente, uma opção diferente, você deverá reinstalar o produto com a opção de raiz de contexto $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -newApplicationHome '$3' está apontando para o novo diretório de configuração do servidor JTS, por exemplo, 'JazzInstallRoot/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo "Se você estiver fazendo upgrade de uma liberação anterior, assegure-se de que tenha selecionado as raízes de contexto corretas.  Por exemplo, se estiver usando o Installation Manager, você deverá selecionar a opção de raiz de contexto $5 no painel "Opções de Raiz de Contexto".  Se tiver selecionado, acidentalmente, uma opção diferente, você deverá reinstalar o produto com a opção de raiz de contexto $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "Não é possível localizar o comando JTS repotools '$2'."
echo ""
echo "Verifique se o parâmetro -oldJTSHome '$3' está apontando para o diretório de configuração antigo do servidor JTS, por exemplo, 'JazzInstallRoot/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldJTSHome '$3' está apontando para o diretório de configuração antigo do servidor JTS, por exemplo, 'JazzInstallRoot/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "Não é possível localizar o comando JTS repotools '$2'."
echo ""
echo "Verifique se o parâmetro -newJTSHome '$3' está apontando para o novo diretório de configuração do servidor JTS, por exemplo, 'JazzInstallRoot/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -newJTSHome '$3' está apontando para o novo diretório de configuração do servidor JTS, por exemplo, 'JazzInstallRoot/server/conf', e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Um arquivo tar que contenha dados 2.x é necessário para o upgrade de $2."
echo "Use -help para obter uma descrição completa dos parâmetros."
echo ""
;;


# **********************
# * Mensagens de execução *
# **********************

BANNER_jts )
echo ""
echo ""
echo "===================================================="
echo "===     Upgrade do JTS da $2 para a 3.0.1.2     ==="
echo "===================================================="
echo ""
;;

BANNER_ccm )
echo ""
echo ""
echo "=================================================="
echo "===     Upgrade do CCM de $2 para 3.0.1.2     ==="
echo "=================================================="
echo ""
;;

BANNER_qm )
echo ""
echo ""
echo "==================================================="
echo "===     Upgrade do QM da $2 para a 3.0.1.2     ==="
echo "==================================================="
echo ""
;;

BANNER_rm )
echo ""
echo ""
echo "==================================================="
echo "===     Upgrade do RM da $2 para a 3.0.1.2     ==="
echo "==================================================="
echo ""
;;


# *********************
# * Comutador First Step *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "Última execução falhou na etapa inicial..."
;;

LAST_STEP_FAILED )
echo ""
echo "Última execução falhou na etapa $2..."
echo "Deseja reiniciar o upgrade a partir desta etapa ou de uma anterior?"
;;

ALREADY_RUN )
echo ""
echo "O upgrade já foi feito e concluído com sucesso..."
echo "Deseja reiniciar um novo a partir de uma etapa específica?"
;;

LAST_STEP_PASSED )
echo ""
echo "Última execução foi interrompida com sucesso na etapa $2..."
echo "Deseja reiniciar o upgrade a partir da etapa $3 atual ou de uma anterior?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Insira o número da etapa [$2-$3] a partir da qual deseja reiniciar o upgrade ou [Enter] para Cancelar:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' não é um número. Insira um número de etapa válido."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' é um número de etapa inválido. Insira um número de etapa válido."
;;

MAX_STEP_NUMBER )
echo ""
echo "A última etapa é a etapa $2, portanto, não é possível reiniciar o upgrade na etapa $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "A etapa $2 não foi executada ainda, portanto, não é possível reiniciar o upgrade na etapa $3."
;;


# **********************
# * Mensagens para Etapas *
# **********************

STEP_0_IBMi )
echo "Etapa 0: Eliminar tabelas"
echo "-------------------------"
;;

STEP_0 )
echo "Etapa 0: Atualizar arquivos de configuração"
echo "-------------------------------------------"
;;

STEP_1_ADD )
echo "Etapa 1: Incluir tabelas"
echo "------------------------"
;;

STEP_1_IMPORT )
echo "Etapa 1: Importar dados $2"
echo "------------------------------------"
;;

STEP_2_EXPORT_USER_INFO )
echo "Etapa 2: Exportar informações do usuário do banco de dados do aplicativo"
echo "------------------------------------------------------------------------"
;;

STEP_2_COPY_TEXT_INDICES )
echo "Etapa 2: Copiar índices de texto"
echo "--------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Etapa 2: Fazer upgrade do esquema de armazém de dados"
echo "-----------------------------------------------------"
;;

STEP_3_IMPORT_USER_INFO )
echo "Etapa 3: Importar informações sobre o usuário para o banco de dados JTS"
echo "-----------------------------------------------------------------------"
;;

STEP_3_UPGRADE_DATA_WAREHOUSE )
echo "Etapa 3: Fazer upgrade do esquema de armazém de dados"
echo "-----------------------------------------------------"
;;

STEP_4 )
echo "Etapa 4: Importar Informações sobre o usuário JTS para o banco de dados do aplicativo"
echo "-------------------------------------------------------------------------------------"
;;

STEP_5 )
echo "Etapa $2: Reconstruir índices do texto"
echo "-------------------------------------"
;;

STEP_6 )
echo "Etapa $2: Recriar consulta e índices de procura"
echo "----------------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "A atualização $2 falhou na etapa $3.  Corrija o problema e execute o script novamente começando na etapa $3."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_JTS )
echo ""
echo "A atualização $2 foi bem-sucedida.  Inicie o servidor e use o assistente de configuração JTS para validar a configuração JTS.  Também é possível atualizar quaisquer aplicativos no seu ambiente agora."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_RM )
echo ""
echo "A porção off-line da atualização $2 foi bem-sucedida.  Inicie o servidor e navegue para o assistente de migração $2 para concluir a migração on-line."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_CCM_QM )
echo ""
echo "A atualização $2 foi bem sucedida.  Iniciar os servidores em sua implementação.  Se o JTS não foi configurado, utilize o assistente de configuração para configurar o JTS e registrar o aplicativo.  Caso contrário, registre o aplicativo na página de administração do servidor do JTS."
echo ""
;;

# *******************************
# * Mensagens ao executar etapa *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Diretório: $2"
echo "Comando:"
;;

ENTER_STEP_ACTION )
echo "Insira [E] para executar esta etapa, [S] para ignorá-la ou pressione [Enter] para cancelar a execução do script:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' é uma etapa inválida, apenas 'E', 'S' ou 'Enter' são permitidos"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Um editor vi será aberto para permitir que você verifique o arquivo teamserver.properties $2."
echo "Verifique se a raiz de URI Público denotada pela propriedade com.ibm.team.repository.server.webapp.url está correta."
echo "Verifique se as propriedades do banco de dados estão corretas."
echo "Quando concluído, salve as mudanças se houver alguma e feche o editor para continuar a execução do script."
echo ""
echo "Consulte o tópico 'Atualizando o Jazz Team Server e os aplicativos de CLM' do InfoCenter"
echo "para obter informações sobre como configurar adequadamente cada propriedade:"
echo "http://publib.boulder.ibm.com/infocenter/clmhelp/v3r0m1/topic/com.ibm.jazz.install.doc/topics/t_update_prepare_config.html"
;;

PAUSE )
echo ""
echo "Insira [C] para continuar a execução ou pressione [Enter] para cancelar a execução do script:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' é uma entrada inválida, somente 'C' ou 'Enter' são permitidos"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "Falha ao copiar os índices de texto de '$2' para '$3'."
echo "Verifique a propriedade com.ibm.team.fulltext.indexLocation definida no"
echo "arquivo teamserver.properties."
echo "Copiar manualmente os índices de texto para esse diretório e executar"
echo "o repotools -rebuildTextIndices para reconstruí-los."
echo ""
;;

# *****************************************
# * Mensagens para verificação de URIs Públicos *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERRO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Não há nenhuma URI Pública em"
echo "$3,"
echo "portanto, o upgrade não pode ser iniciado."
echo ""
echo "Deve haver um URI Público neste arquivo definido conforme a seguir:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "A propriedade de URI Público com.ibm.team.repository.server.webapp.url deve estar presente no arquivo teamserver.properties."
echo "Inclua a propriedade no 2.x do arquivo teamserver.properties e configure o valor para ser a raiz do URI que todos os clientes usam para atingir o servidor."
echo "A raiz de URI Público é essencial para o funcionamento adequado de seu servidor 3.0.1.x. A atualização não será concluída com sucesso sem esta propriedade."
echo "Para obter mais informações, consulte o tópico do InfoCenter sobre 'Planejar seus URIs' em:"
echo "http://publib.boulder.ibm.com/infocenter/clmhelp/v3r0m1/topic/com.ibm.jazz.install.doc/topics/c_planning_URLs.html"
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERRO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Todas as URIs Públicas definidas em"
echo "$3,"
echo "possuem linhas de comentários, portanto, o upgrade não pode ser iniciado."
echo ""
echo "Deve haver um URI Público com o comentário removido neste arquivo definido conforme a seguir:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "A propriedade de URI Público com.ibm.team.repository.server.webapp.url deve estar presente no arquivo teamserver.properties."
echo "Inclua a propriedade no 2.x do arquivo teamserver.properties e configure o valor para ser a raiz do URI que todos os clientes usam para atingir o servidor."
echo "A raiz de URI Público é essencial para o funcionamento adequado de seu servidor 3.0.1.x. A atualização não será concluída com sucesso sem esta propriedade."
echo "Para obter mais informações, consulte o tópico do InfoCenter sobre 'Planejar seus URIs' em:"
echo "http://publib.boulder.ibm.com/infocenter/clmhelp/v3r0m1/topic/com.ibm.jazz.install.doc/topics/c_planning_URLs.html"
echo ""
;;

esac

}
