#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2011. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # ccm_upgrade.sh スクリプト・パラメーターとそのデフォルト
# # 値に対応する環境変数の定義
# #
# #===========================================================
# #
# # このファイルは、ccm_upgrade.sh スクリプトの実行の開始時に
# # 読み取られます。これは、定義済みのデフォルト値がある
# # 有効なパラメーターごとに 1 つの環境変数を設定します。
# #
# # ユーザーは、デフォルト値を変更して ccm_upgrade.sh スクリ
# # プトを独自の値で起動することもできます。そうすれば、コマン
# # ド行でパラメーターとそれに対応する値を手動で入力する必要
# # はありません。
# #
# # 警告:
# # すべてのアプリケーションにすべての変数を設定する必要は
# # ありません。値を変更する前に、それぞれのコメントを
# # 注意深くお読みください。
# #
# #############################################################

# パラメーター: -oldApplicationHome
# 使用法: -oldApplicationHome <ディレクトリー・パス>
# 説明:
# 	2.x または 3.0.x インストール済み環境でのアプリケーション・ホーム・ディレクトリーの絶対パス。
# デフォルト:
# 	<なし>
# 制約:
#  - これは必須パラメーターです。
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#    例: /Jazz/IBM/RTC_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# パラメーター: -applicationContextRoot
# 使用法: -applicationContextRoot<root>
# 説明:
# 	2.x または 3.0.x サーバーのアプリケーション・コンテキスト・ルート。
# デフォルト:
# 	jazz (2.x), ccm (3.0.1)
# 制約:
#  - <ルート> は有効な単一のディレクトリー名 (前にスラッシュがないもの) でなければなりません。
#
APPLICATION_CONTEXT_ROOT=

# パラメーター: -oldApplicationVersion
# 使用法: -oldApplicationVersion <version>
# 説明:
# 	アップグレードする 3.x バージョン。デフォルトでは、古いアプリケーションに対して repotools -version を実行する操作でこの値が判別されます。
# デフォルト:
# 	<なし>
# 制約:
#  - 2.x バージョンからアップグレードする場合は、指定しないでください
#  - 完全なバージョン・ストリング (3.0.0 や 3.0.1 など) にしてください
#
OLD_APPLICATION_VERSION=

# パラメーター: -updateTomcatFiles
# 使用法: -updateTomcatFiles <yes | no>
# 説明:
# 	Tomcat 構成ファイルを更新するかどうか。
# デフォルト:
# 	yes
# 制約:
#  - 有効値は「yes」および「no」のみです。
#
UPDATE_TOMCAT_FILES=yes

# パラメーター: -oldTomcatHome
# 使用法: -oldTomcatHome <ディレクトリー・パス>
# 説明:
# 	2.x または 3.0.x インストール済み環境での Tomcat ルート・ディレクトリーの絶対パス。
# デフォルト:
# 	<なし>
# 制約:
#  - 既存のディレクトリーでなければなりません。
#
OLD_TOMCAT_HOME=

# パラメーター: -newApplicationHome
# 使用法: -newApplicationHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールでのアプリケーション・ホーム・ディレクトリーのパス。
# デフォルト:
# 	conf
# 制約:
#  - RTC、QM、および RM アップグレードの場合のみ受け入れられます。
#  - 受け入れられた場合、これは必須パラメーターとなります。
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#    例: /Jazz/IBM/RTC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# パラメーター: -newJTSHome
# 使用法: -newJTSHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールの JTS サーバー構成ディレクトリーのパス。
# デフォルト:
# 	新規のアプリケーション・ホーム・ディレクトリー
# 制約:
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#
NEW_JTS_HOME=

# パラメーター: -jtsContextRoot
# 使用法: -jtsContextRoot <ルート>
# 説明:
# 	3.0.1.2 JTS サーバーのコンテキスト・ルート。
# デフォルト:
# 	jts
# 制約:
#  - <ルート> は有効な単一のディレクトリー名 (前にスラッシュがないもの) でなければなりません。
#
JTS_CONTEXT_ROOT=jts

# パラメーター: -newApplicationTomcatHome
# 使用法: -newApplicationTomcatHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールでのアプリケーション Tomcat ルート・ディレクトリーのパス。
# デフォルト:
# 	<なし>
#
NEW_TOMCAT_HOME=

# パラメーター: -newJTSTomcatHome
# 使用法: -newJTSTomcatHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールでの JTS Tomcat ルート・ディレクトリーのパス。
# デフォルト:
# 	<なし>
#
NEW_JTS_TOMCAT_HOME=

# パラメーター: -noPrompt
# 使用法: -noPrompt
# 説明:
# 	表を作成または変更する前にプロンプトを出しません。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「noPrompt」のみです。
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# パラメーター: -noVerify
# 使用法: -noVerify
# 説明:
# 	teamserver.properties ファイルの検査を実行しません。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「noVerify」のみです。
#
# NO_VERIFY=noVerify
NO_VERIFY=

# パラメーター: -overwrite
# 使用法: -overwrite
# 説明:
# 	既存のファイルをすべて上書きするかどうか。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「overwrite=yes」のみです。
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# パラメーター: -importFromFile
# 使用法: -importFromFile <ファイル・パス>
# 説明:
# 	2.x または 3.0.x でエクスポートされた tar ファイルからデータをインポートします。
# デフォルト:
# 	<なし>
# 制約:
#  - パスは、既存の有効なファイルを指している必要があります。
#
IMPORT_FROM_FILE=

# パラメーター: -noStepPrompt
# 使用法: -noStepPrompt
# 説明:
# 	ステップを実行する前にプロンプトを出しません。
# デフォルト:
# 	false
# 制約:
#  - 有効値は「true」または「false」のみです。
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
