#!/bin/sh
# *******************************************************************************
#  Lizenzmaterial - Eigentum der IBM
#  (c) Copyright IBM Corporation 2006, 2011. Alle Rechte vorbehalten.
#
# *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Umgebungsvariablen gemäß den Parametern und Standard-
# # werten im Script jts_upgrade.sh definieren
# #
# #===========================================================
# #
# # Diese Datei wird zu Beginn der Ausführung des Scripts
# # jts_upgrade.sh gelesen. Pro gültigem Parameter wird eine
# # Umgebungsvariable mit vordefiniertem Standardwert gesetzt.
# #
# # Benutzer können den Standardwert modifizieren und das
# # Script jts_upgrade.sh mit eigenen Werten starten. Die
# # Parameter und ihre Werte müssen dann nicht manuell in
# # der Befehlszeile eingegeben werden.
# #
# # WARNUNG:
# # Nicht alle Variablen müssen für jede Anwendung gesetzt
# # werden. Modifizieren Sie einen Wert erst, nachdem Sie
# # sorgfältig den zugehörigen Kommentar gelesen haben.
# #
# #############################################################

# Parameter: -oldJTSHome
# Syntax: -oldJTSHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum JTS-Ausgangsverzeichnis in der 3.0.x-Installation
# Standardwert:
# 	<ohne>
# Hinweis:
#     Ist dieser Parameter angegeben, wird für RTC und JTS ein Upgrade von
#     Version 3.0 auf Version 3.0.1 durchgeführt. Andernfalls ist
#     unabhängig vom jeweiligen Upgrade nur RTC betroffen.
# Einschränkungen:
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das
#    mit 'server/conf' endet.
#  - Nur gültig für RM- und JTS-Upgrades
#
OLD_JTS_HOME=

# Parameter: -jtsContextRoot
# Syntax: -jtsContextRoot <Stammverzeichnis>
# Beschreibung:
# 	JTS-Kontextstammverzeichnis
# Standardwert:
# 	jts
# Einschränkungen:
#  - <Stammverzeichnis> muss ein gültiger Verzeichnisname
#    ohne vorangestellten Schrägstrich sein.
#
JTS_CONTEXT_ROOT=jts

# Parameter: -oldJTSVersion
# Syntax: -oldJTSVersion <version>
# Beschreibung:
# 	Die 3.x-Version, für die ein Upgrade druchgeführt wird. Standardmäßig wird
#  dies durch Ausführen von repotools -version gegen auf der alten JTS ermittelt.
# Standard:
# 	<keiner>
# Einschränkungen:
#  - Muss eine vollständige Versionszeichenfolge sein
#    Beispiel: 3.0.0 oder 3.0.1
#
OLD_JTS_VERSION=

# Parameter: -updateTomcatFiles
# Syntax: -updateTomcatFiles <yes | no>
# Beschreibung:
# 	Angabe, ob die Tomcat-Konfigurationsdateien aktualisiert
#  werden sollen.
# Standardwert:
# 	yes
# Einschränkungen:
#  - Gültig sind nur die Werte 'yes' und 'no'.
#
UPDATE_TOMCAT_FILES=yes

# Parameter: -oldTomcatHome
# Syntax: -oldTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum Tomcat-Stammverzeichnis in der 3.0.x-Installation
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Das Verzeichnis muss vorhanden sein.
#
OLD_TOMCAT_HOME=

# Parameter: -newJTSHome
# Syntax: -newJTSHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum JTS-Serverkonfigurationsverzeichnis der 3.0.1.2-Installation
# Standardwert:
# 	conf
# Einschränkungen:
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conf' endet.
#
NEW_JTS_HOME="$START_DIR/conf"

# Parameter: -newTomcatHome
# Syntax: -newTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Tomcat-Ausgangsverzeichnis der 3.0.1.2-Installation
# Standardwert:
# 	<ohne>
#
NEW_TOMCAT_HOME=

# Parameter: -noPrompt
# Syntax: -noPrompt
# Beschreibung:
# 	Beim Erstellen oder Modifizieren der Tabellen keine Bestätigung anfordern
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Die einzigen gültigen Werte sind eine leere Zeichenfolge und 'noPrompt'.
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parameter: -noVerify
# Syntax: -noVerify
# Beschreibung:
# 	Keine Verifizierung für Team-Server-Eigenschaftendateien durchführen
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Gültig sind nur eine leere Zeichenfolge und 'noVerify'.
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parameter: -overwrite
# Syntax: -overwrite
# Beschreibung:
# 	Angabe, ob vorhandene Dateien überschrieben werden sollen
# Standardwert:
# 	no
# Einschränkungen:
#  - Gültig sind nur eine leere Zeichenfolge und 'overwrite=yes'.
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parameter: -noStepPrompt
# Syntax: -noStepPrompt
# Beschreibung:
# 	Keine Bestätigung für die Ausführung eines Schrittes anfordern
# Standardwert:
# 	false
# Einschränkungen:
#  - Gültig sind nur die Werte 'true' und 'false'.
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
