#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2011. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Définissez les variables d'environnement correspondant
# # aux paramètres de script jts_upgrade.sh ainsi que leurs
# # valeurs par défaut
# #
# #===========================================================
# #
# # Ce fichier est lu au début de l'exécution du script
# # jts_upgrade.sh. Il associe une variable d'environnement
# # par paramètre valide à une valeur par défaut prédéfinie.
# #
# # Les utilisateurs peuvent modifier la valeur par défaut
# # pour lancer le script jts_upgrade.sh avec leurs propres
# # valeurs sans avoir à entrer manuellement le paramètre et
# # sa valeur correspondante sur la ligne de commande.
# #
# # AVERTISSEMENT :
# # Les variables ne doivent pas toutes être définies, selon
# # l'application mise à niveau.  Lisez attentivement chaque
# # commentaire avant de modifier la valeur.
# #
# #############################################################

# Paramètre : -oldJTSHome
# Syntaxe : -oldJTSHome <chemin répertoire>
# Description :
# 	Chemin d'accès complet au répertoire principal du serveur JTS dans l'installation 3.0.x.
# Valeur par défaut :
# 	<aucune>
# Remarque :
#     S'il est spécifié, cela signifie qu'une mise à niveau de la version 3.0 vers la
#     version 3.0.1 va avoir lieu pour RTC et JTS. Sinon, seul RTC est concerné, quel
#     que soit le type de mise à niveau détecté...
# Contraintes :
#  - <chemin répertoire> doit correspondre à un répertoire existant qui se termine par 'server/conf'.
#  - Valide uniquemement pour les mises à niveau de RM et de JTS.
#
OLD_JTS_HOME=

# Paramètre : -jtsContextRoot
# Syntaxe : -jtsContextRoot <racine>
# Description :
# 	La racine de contexte du serveur JTS
# Valeur par défaut :
# 	jts
# Contraintes :
#  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début).
#
JTS_CONTEXT_ROOT=jts

# Paramètre : -oldJTSVersion
# Syntaxe : -oldJTSVersion <version>
# Description :
# 	Version 3.x mise à niveau. Par défaut, vous pouvez la déterminer en exécutant repotools -version pour l'ancien serveur JTS. Valeur par défaut :
# 	<none>
# Contraintes :
#  - doit être une chaîne de version complète de type 3.0.0 ou 3.0.1
#
OLD_JTS_VERSION=

# Paramètre : -updateTomcatFiles
# Syntaxe : -updateTomcatFiles <yes | no>
# Description :
# 	Indique si les fichiers de configuration Tomcat doivent être mis à jour.
# Valeur par défaut :
# 	yes
# Contraintes :
#  - Les seules valeurs admises sont 'yes' et 'no'.
#
UPDATE_TOMCAT_FILES=yes

# Paramètre : -oldTomcatHome
# Syntaxe : -oldTomcatHome <chemin répertoire>
# Description :
# 	Chemin d'accès complet au répertoire principal de Tomcat dans l'installation 3.0.x.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Doit correspondre à un répertoire existant
#
OLD_TOMCAT_HOME=

# Paramètre : -newJTSHome
# Syntaxe : -newJTSHome <chemin répertoire>
# Description :
# 	Chemin d'accès au répertoire de configuration du serveur JTS de l'installation 3.0.1.2.
# Valeur par défaut :
# 	conf
# Contraintes :
#  - <chemin répertoire> doit correspondre à un répertoire existant qui se termine par 'server/conf'.
#
NEW_JTS_HOME="$START_DIR/conf"

# Paramètre : -newTomcatHome
# Syntaxe : -newTomcatHome <chemin répertoire>
# Description :
# 	Chemin d'accès au répertoire principal Tomcat de l'installation 3.0.1.2.
# Valeur par défaut :
# 	<aucune>
#
NEW_TOMCAT_HOME=

# Paramètre : -noPrompt
# Syntaxe : -noPrompt
# Description :
# 	Ne pas demander confirmation avant la création ou la modification des tables.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Les seules valeurs admises sont la valeur vide et 'noPrompt'.
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Paramètre : -noVerify
# Syntaxe : -noVerify
# Description :
# 	Ne pas vérifier les fichiers teamserver.properties.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Les seules valeurs admises sont la valeur vide et 'noVerify'.
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Paramètre : -overwrite
# Syntaxe : -overwrite
# Description :
# 	Indique si les fichiers existants doivent être remplacés.
# Valeur par défaut :
# 	no
# Contraintes :
#  - Les seules valeurs admises sont la valeur vide et 'overwrite=yes'.
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Paramètre : -noStepPrompt
# Syntaxe : -noStepPrompt
# Description :
# 	Ne pas demander confirmation avant l'exécution d'une étape.
# Valeur par défaut :
# 	false
# Contraintes :
#  - Les seules valeurs admises sont 'true' et 'false'.
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
