#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2011. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # jts_upgrade.sh スクリプト・パラメーターとそのデフォルト
# # 値に対応する環境変数の定義
# #
# #===========================================================
# #
# # このファイルは、jts_upgrade.sh のスクリプトの実行の開始時に
# # 読み取られます。これは、定義済みのデフォルト値がある
# # 有効なパラメーターごとに 1 つの環境変数を設定します。
# #
# # ユーザーは、デフォルト値を変更して jts_upgrade.sh スクリ
# # プトを独自の値で起動することもできます。そうすれば、コマン
# # ド行でパラメーターとそれに対応する値を手動で入力する必要
# # はありません。
# #
# # 警告:
# # すべてのアプリケーションにすべての変数を設定する必要は
# # ありません。値を変更する前に、それぞれのコメントを
# # 注意深くお読みください。
# #
# #############################################################

# パラメーター: -oldJTSHome
# 使用法: -oldJTSHome <ディレクトリー・パス>
# 説明:
# 	3.0.x インストール済み環境での JTS ホーム・ディレクトリーの絶対パス。
# デフォルト:
# 	<なし>
# 注:
#     これを指定した場合、RTC と JTS の両方で 3.0 から 3.0.1 へのアップ
#     グレードが行われることになります。 そうでない場合、どのような種類の
#     アップグレードが検出されても、関係するのは RTC のみです...
# 制約:
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#  - RM と JTS のアップグレードの場合にのみ有効です。
#
OLD_JTS_HOME=

# パラメーター: -jtsContextRoot
# 使用法: -jtsContextRoot <ルート>
# 説明:
# 	JTS コンテキスト・ルート。
# デフォルト:
# 	jts
# 制約:
#  - <ルート> は有効な単一のディレクトリー名 (前にスラッシュがつかないもの) でなければなりません。
#
JTS_CONTEXT_ROOT=jts

# パラメーター: -oldJTSVersion
# 使用法: -oldJTSVersion <version>
# 説明:
# 	アップグレードする 3.x バージョン。デフォルトでは、古い JTS に対して repotools -version を実行する操作でこの値が判別されます。
# デフォルト:
# 	<なし>
# 制約:
#  - 完全なバージョン・ストリング (3.0.0 や 3.0.1 など) にしてください
#
OLD_JTS_VERSION=

# パラメーター: -updateTomcatFiles
# 使用法: -updateTomcatFiles <yes | no>
# 説明:
# 	Tomcat 構成ファイルを更新するかどうか。
# デフォルト:
# 	yes
# 制約:
#  - 有効値は「yes」および「no」のみです。
#
UPDATE_TOMCAT_FILES=yes

# パラメーター: -oldTomcatHome
# 使用法: -oldTomcatHome <ディレクトリー・パス>
# 説明:
# 	3.0.x インストール済み環境での Tomcat ルート・ディレクトリーの絶対パス。
# デフォルト:
# 	<なし>
# 制約:
#  - 既存のディレクトリーでなければなりません。
#
OLD_TOMCAT_HOME=

# パラメーター: -newJTSHome
# 使用法: -newJTSHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールの JTS サーバー構成ディレクトリーのパス。
# デフォルト:
# 	conf
# 制約:
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#
NEW_JTS_HOME="$START_DIR/conf"

# パラメーター: -newTomcatHome
# 使用法: -newTomcatHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールの Tomcat ホーム・ディレクトリーのパス。
# デフォルト:
# 	<なし>
#
NEW_TOMCAT_HOME=

# パラメーター: -noPrompt
# 使用法: -noPrompt
# 説明:
# 	表を作成または変更する前にプロンプトを出しません。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「noPrompt」のみです。
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# パラメーター: -noVerify
# 使用法: -noVerify
# 説明:
# 	teamserver.properties ファイルの検査を実行しません。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「noVerify」のみです。
#
# NO_VERIFY=noVerify
NO_VERIFY=

# パラメーター: -overwrite
# 使用法: -overwrite
# 説明:
# 	既存のファイルをすべて上書きするかどうか。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「overwrite=yes」のみです。
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# パラメーター: -noStepPrompt
# 使用法: -noStepPrompt
# 説明:
# 	ステップを実行する前にプロンプトを出しません。
# デフォルト:
# 	false
# 制約:
#  - 有効値は「true」または「false」のみです。
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
