#!/bin/sh
# *******************************************************************************
#  Lizenzmaterial - Eigentum der IBM
#  (c) Copyright IBM Corporation 2006, 2011. Alle Rechte vorbehalten.
#
# *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Umgebungsvariablen gemäß den Parametern und Standard-
# # werten im Script qm_upgrade.sh definieren
# #
# #===========================================================
# #
# # Diese Datei wird zu Beginn der Ausführung des Scripts
# # qm_upgrade.sh gelesen. Pro gültigem Parameter wird eine
# # Umgebungsvariable mit vordefiniertem Standardwert gesetzt.
# #
# # Benutzer können den Standardwert modifizieren und das
# # Script qm_upgrade.sh mit eigenen Werten starten. Die
# # Parameter und ihre Werte müssen dann nicht manuell in
# # der Befehlszeile eingegeben werden.
# #
# # WARNUNG:
# # Nicht alle Variablen müssen für jede Anwendung gesetzt
# # werden. Modifizieren Sie einen Wert erst, nachdem Sie
# # sorgfältig den zugehörigen Kommentar gelesen haben.
# #
# #############################################################

# Parameter: -oldApplicationHome
# Syntax: -oldApplicationHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum Ausgangsverzeichnis für Anwendungen
#  in einer 2.x- oder 3.0.x-Installation
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Dies ist ein obligatorischer Parameter.
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conf' endet, z. B. /Jazz/IBM/RQM_2.x/jazz/server/conf.
#
OLD_APPLICATION_HOME=

# Parameter: -applicationContextRoot
# Syntax: -applicationContextRoot<Stammverzeichnis>
# Beschreibung:
# 	Kontextstammverzeichnis für Anwendungen im 2.x- oder 3.0.x-Server
# Standardwert:
# 	jazz (2.x), qm (3.0.1)
# Einschränkungen:
#  - <Stammverzeichnis> muss ein gültiger Verzeichnisname
#    ohne vorangestellten Schrägstrich sein.
#
APPLICATION_CONTEXT_ROOT=

# Parameter: -updateTomcatFiles
# Syntax: -updateTomcatFiles <yes | no>
# Beschreibung:
# 	Angabe, ob die Tomcat-Konfigurationsdateien aktualisiert
#  werden sollen.
# Standardwert:
# 	yes
# Einschränkungen:
#  - Gültig sind nur die Werte 'yes' und 'no'.
#
UPDATE_TOMCAT_FILES=yes

# Parameter: -oldTomcatHome
# Syntax: -oldTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum Tomcat-Stammverzeichnis in einer 2.x- oder 3.0.x-Installation
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Das Verzeichnis muss vorhanden sein.
#
OLD_TOMCAT_HOME=

# Parameter: -newApplicationHome
# Syntax: -newApplicationHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Ausgangsverzeichnis für Anwendungen in der 3.0.1.2-Installation
# Standardwert:
# 	conf
# Einschränkungen:
#  - Nur für RTC-, QM- und RM-Upgrades akzeptiert und
#    in diesen Fällen ein obligatorischer Parameter
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conf' endet, z. B. /Jazz/IBM/RQM_3.0/JazzTeamServer/server/conf.
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parameter: -newJTSHome
# Syntax: -newJTSHome <Verzeichnispfad>
# Beschreibung:
# 	Vollständiger Pfad zum JTS-Ausgangsverzeichnis in der 3.0.1.2-Installation
# Standardwert:
# 	Das Ausgangsverzeichnis der neuen Anwendung
# Einschränkungen:
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit
#    'server/conf' endet, z. B. /Jazz/IBM/RQM_3.0/JazzTeamServer/server/conf.
#
NEW_JTS_HOME=

# Parameter: -jtsContextRoot
# Syntax: -jtsContextRoot <Stammverzeichnis>
# Beschreibung:
# 	Kontextstammverzeichnis von JTS 3.0.1.2
# Standardwert:
# 	jts
# Einschränkungen:
#  - <Stammverzeichnis> muss ein gültiger Verzeichnisname
#    ohne vorangestellten Schrägstrich sein.
#
JTS_CONTEXT_ROOT=jts

# Parameter: -newApplicationTomcatHome
# Syntax: -newApplicationTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Tomcat-Stammverzeichnis für Anwendungen in der 3.0.1.2-Installation
# Standardwert:
# 	<ohne>
#
NEW_TOMCAT_HOME=

# Parameter: -newJTSTomcatHome
# Syntax: -newJTSTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Tomcat-Stammverzeichnis für JTS in der 3.0.1.2-Installation
# Standardwert:
# 	<ohne>
#
NEW_JTS_TOMCAT_HOME=

# Parameter: -noPrompt
# Syntax: -noPrompt
# Beschreibung:
# 	Beim Erstellen oder Modifizieren der Tabellen keine Bestätigung anfordern
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Die einzigen gültigen Werte sind eine leere Zeichenfolge und 'noPrompt'.
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parameter: -noVerify
# Syntax: -noVerify
# Beschreibung:
# 	Keine Verifizierung für Team-Server-Eigenschaftendateien durchführen
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Gültig sind nur eine leere Zeichenfolge und 'noVerify'.
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parameter: -overwrite
# Syntax: -overwrite
# Beschreibung:
# 	Angabe, ob vorhandene Dateien überschrieben werden sollen
# Standardwert:
# 	no
# Einschränkungen:
#  - Gültig sind nur eine leere Zeichenfolge und 'overwrite=yes'.
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parameter: -importFromFile
# Syntax: -importFromFile <Dateipfad>
# Beschreibung:
# 	Daten der exportierten TAR-Datei von Version 2.x oder 3.0.x importieren
# Standardwert:
# 	<ohne>
# Einschränkungen:
#  - Der Pfad muss auf eine vorhandene gültige Datei zeigen
#
IMPORT_FROM_FILE=

# Parameter: -noStepPrompt
# Syntax: -noStepPrompt
# Beschreibung:
# 	Keine Bestätigung für die Ausführung eines Schrittes anfordern
# Standardwert:
# 	false
# Einschränkungen:
#  - Gültig sind nur die Werte 'true' und 'false'.
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
