#!/bin/sh
# *******************************************************************************
#  Materiales bajo licencia - Propiedad de IBM
#  (c) Copyright IBM Corporation 2006, 2011. Reservados todos los derechos.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Defina las variables de entorno correspondientes a los
# # parámetros del script qm_upgrade.sh y sus valores predeterminados.
# #
# #===========================================================
# #
# # Este archivo se lee en el comienzo de la ejecución
# # del script qm_upgrade.sh. Define una variable de entorno por
# # cada parámetro válido con un valor predeterminado predefinido.
# #
# # Es posible que los usuarios deseen modificar el valor predeterminado
# # para lanzar el script qm_upgrade.sh con sus propios valores
# # sin tener que especificar de forma manual el parámetro y su
# # valor correspondiente en la línea de mandatos.
# #
# # AVISO:
# # No es necesario definir todas las variables para cada
# # aplicación.  Lea cada comentario detenidamente antes de modificar
# # el valor.
# #
# #############################################################

# Parámetro: -oldApplicationHome
# Uso: -oldApplicationHome <vía_acceso_dir>
# Descripción:
# 	Vía de acceso completa al directorio de inicio de la aplicación en la instalación de 2.x o 3.0.x.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - este es un parámetro obligatorio
#  - <vía_acceso_dir> debe ser un directorio existente que termine en 'server/conf'
#    por ej. /Jazz/IBM/RQM_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Parámetro: -applicationContextRoot
# Uso: -applicationContextRoot<raíz>
# Descripción:
# 	Raíz de contexto de la aplicación del servidor 2.x o 3.0.x.
# Valor predeterminado:
# 	jazz (2.x), qm (3.0.1)
# Restricciones:
#  - <raíz> debe ser un nombre único de directorio válido (es decir, ninguna barra inclinada inicial)
#
APPLICATION_CONTEXT_ROOT=

# Parámetro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descripción:
# 	Si deben actualizarse los archivos de configuración tomcat.
# Valor predeterminado:
# 	yes
# Restricciones:
#  - Los únicos valores válidos son 'yes' y 'no'
#
UPDATE_TOMCAT_FILES=yes

# Parámetro: -oldTomcatHome
# Uso: -oldTomcatHome <vía_acceso_dir>
# Descripción:
# 	Vía de acceso completa al directorio raíz de Tomcat en la instalación 2.x o 3.0.x.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Debe ser un directorio existente
#
OLD_TOMCAT_HOME=

# Parámetro: -newApplicationHome
# Uso: -newApplicationHome <vía_acceso_dir>
# Descripción:
# 	Vía de acceso al directorio de inicio de aplicación de la instalación 3.0.1.2.
# Valor predeterminado:
# 	conf
# Restricciones:
#  - Solo se acepta en actualizaciones de RTC, QM y RM
#  - Cuando se acepta, es un parámetro obligatorio
#  - <vía_acceso_dir> debe ser un directorio existente que termine en 'server/conf'
#    por ej. /Jazz/IBM/RQM_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parámetro: -newJTSHome
# Uso: -newJTSHome <vía_acceso_dir>
# Descripción:
# 	Vía de acceso completa al directorio de inicio de JTS de la instalación 3.0.1.2.
# Valor predeterminado:
# 	El nuevo directorio de inicio de aplicación
# Restricciones:
#  - <vía_acceso_dir> debe ser un directorio existente que termine en 'server/conf'
#    por ej. /Jazz/IBM/RQM_3.0/JazzTeamServer/server/conf
#
NEW_JTS_HOME=

# Parámetro: -jtsContextRoot
# Uso: -jtsContextRoot <raíz>
# Descripción:
# 	Raíz de contexto del servidor JTS 3.0.1.2.
# Valor predeterminado:
# 	jts
# Restricciones:
#  - <raíz> debe ser un nombre único de directorio válido (es decir, ninguna barra inclinada inicial)
#
JTS_CONTEXT_ROOT=jts

# Parámetro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <vía_acceso_dir>
# Descripción:
# 	Vía de acceso al directorio raíz Tomcat de aplicación de la instalación 3.0.1.2.
# Valor predeterminado:
# 	<ninguno>
#
NEW_TOMCAT_HOME=

# Parámetro: -newJTSTomcatHome
# Uso: -newJTSTomcatHome <vía_acceso_dir>
# Descripción:
# 	Vía de acceso al directorio raíz Tomcat JTS de la instalación 3.0.1.2.
# Valor predeterminado:
# 	<ninguno>
#
NEW_JTS_TOMCAT_HOME=

# Parámetro: -noPrompt
# Uso: -noPrompt
# Descripción:
# 	No mostrar solicitud antes de crear o modificar las tablas
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los únicos valores válidos son en blanco o 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parámetro: -noVerify
# Uso: -noVerify
# Descripción:
# 	No realizar verificación de los archivos teamserver.properties.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los únicos valores válidos son en blanco o 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parámetro: -overwrite
# Uso: -overwrite
# Descripción:
# 	Si debe sobrescribirse algún archivo existente.
# Valor predeterminado:
# 	no
# Restricciones:
#  - Los únicos valores válidos son en blanco u 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parámetro: -importFromFile
# Uso: -importFromFile <vía_acceso_archivo>
# Descripción:
# 	Importar datos del archivo tar 2.x o 3.0.x exportado.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - La vía de acceso debe apuntar a un archivo válido existente
#
IMPORT_FROM_FILE=

# Parámetro: -noStepPrompt
# Uso: -noStepPrompt
# Descripción:
# 	No mostrar solicitud antes de ejecutar un paso.
# Valor predeterminado:
# 	false
# Restricciones:
#  - Los únicos valores válidos son 'true' o 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
