#!/bin/sh
# *******************************************************************************
#  Materiale su licenza - Proprietà di IBM
#  (c) Copyright IBM Corporation 2006, 2011. Tutti i diritti riservati.
#
#  Nota relativa a limitazioni dei diritti per gli utenti del Governo degli Stati Uniti:
#  L'uso, la duplicazione o la divulgazione sono limitati dal GSA ADP Schedule
#  Contract con IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Definire le variabili d'ambiente corrispondenti ai
# # parametri di script qm_upgrade.sh e ai relativi valori predefiniti
# #
# #===========================================================
# #
# # Questo file viene letto all'inizio dell'esecuzione dello script
# # qm_upgrade.sh. Esso imposta una variabile di ambiente
# # per parametro valido con valore predefinito.
# #
# # Gli utenti possono modificare il valore predefinito per
# # avviare lo script qm_upgrade.sh con i propri valori
# # senza dover immettere il parametro e il corrispondente
# # valore manualmente sulla riga comandi.
# #
# # AVVERTENZA:
# # Non tutte le variabili devono essere impostate in base
# # all'applicazione correntemente aggiornata.  Leggere attentamente ogni commento
# # prima di modificare il valore.
# #
# #############################################################

# Parametro: -oldApplicationHome
# Uso: -oldApplicationHome <percorso dir>
# Descrizione:
# 	Percorso completo della directory home dell'applicazione nell'installazione 2.x o 3.0.x.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Questo è un parametro obbligatorio
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#    ad esempio, /Jazz/IBM/RQM_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Parametro: -applicationContextRoot
# Uso: -applicationContextRoot<root>
# Descrizione:
# 	La root di contesto dell'applicazione del server 2.x o 3.0.x.
# Valore predefinito:
# 	jazz (2.x), qm (3.0.1)
# Limitazioni:
#  - <root> deve essere una singola directory valida (senza barra iniziale)
#
APPLICATION_CONTEXT_ROOT=

# Parametro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descrizione:
# 	Indica se aggiornare i file di configurazione Tomcat.
# Valore predefinito:
# 	yes
# Limitazioni:
#  - Gli unici valori validi sono 'yes' e 'no'
#
UPDATE_TOMCAT_FILES=yes

# Parametro: -oldTomcatHome
# Uso: -oldTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso completo della directory root Tomcat nell'installazione 2.x o 3.0.x.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Deve essere una directory esistente
#
OLD_TOMCAT_HOME=

# Parametro: -newApplicationHome
# Uso: -newApplicationHome <percorso dir>
# Descrizione:
# 	Il percorso della directory home dell'applicazione nell'installazione 3.0.1.2.
# Valore predefinito:
# 	conf
# Limitazioni:
#  - Accettato solo per un aggiornamento RTC, QM e RM
#  - Se accettato, questo è un parametro obbligatorio
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#    ad esempio, /Jazz/IBM/RQM_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parametro: -newJTSHome
# Uso: -newJTSHome <percorso dir>
# Descrizione:
# 	Percorso completo della directory home JTS nell'installazione 3.0.1.2.
# Valore predefinito:
# La nuova directory home dell'applicazione
# Limitazioni:
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#    ad esempio, /Jazz/IBM/RQM_3.0/JazzTeamServer/server/conf
#
NEW_JTS_HOME=

# Parametro: -jtsContextRoot
# Uso: -jtsContextRoot <root>
# Descrizione:
# 	La root di contesto del server JTS 3.0.1.2.
# Valore predefinito:
# 	jts
# Limitazioni:
#  - <root> deve essere una singola directory valida (senza barra iniziale)
#
JTS_CONTEXT_ROOT=jts

# Parametro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso della directory root Tomcat dell'applicazione nell'installazione 3.0.1.2.
# Valore predefinito:
# 	<nessun valore>
#
NEW_TOMCAT_HOME=

# Parametro: -newJTSTomcatHome
# Uso: -newJTSTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso della directory root Tomcat JTS nell'installazione 3.0.1.2.
# Valore predefinito:
# 	<nessun valore>
#
NEW_JTS_TOMCAT_HOME=

# Parametro: -noPrompt
# Uso: -noPrompt
# Descrizione:
# 	Non richiede prima di creare o modificare le tabelle
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Gli unici valori validi sono un valore vuoto o 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parametro: -noVerify
# Uso: -noVerify
# Descrizione:
# 	Non esegue la verifica dei file teamserver.properties.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Gli unici valori validi sono un valore vuoto o 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parametro: -overwrite
# Uso: -overwrite
# Descrizione:
# 	Indica se sovrascrivere un file esistente.
# Valore predefinito:
# 	no
# Limitazioni:
#  - Gli unici valori validi sono il valore vuoto o 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parametro: -importFromFile
# Uso: -importFromFile <percorso file>
# Descrizione:
# 	Importa i dati dal file tar esportato 2.x o 3.0.x.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Il percorso deve fare riferimento a un file esistente valido
#
IMPORT_FROM_FILE=

# Parametro: -noStepPrompt
# Uso: -noStepPrompt
# Descrizione:
# 	Non richiede prima di eseguire un passo.
# Valore predefinito:
# 	false
# Limitazioni:
#  - Gli unici valori validi sono 'true' o 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
