#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2011. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Définissez les variables d'environnement correspondant
# # aux paramètres de script rm_upgrade.sh ainsi que leur
# # valeurs par défaut
# #
# #===========================================================
# #
# # Ce fichier est lu au début de l'exécution du script
# # rm_upgrade.sh. Il associe une variable d'environnement
# # par paramètre valide à une valeur par défaut prédéfinie.
# #
# # Les utilisateurs peuvent modifier la valeur par défaut
# # pour lancer le script rm_upgrade.sh avec leurs propres
# # valeurs sans avoir à entrer manuellement le paramètre et
# # sa valeur correspondante sur la ligne de commande.
# #
# # AVERTISSEMENT :
# # Les variables ne doivent pas toutes être définies, selon
# # l'application mise à niveau.  Lisez attentivement chaque
# # commentaire avant de modifier la valeur.
# #
# #############################################################

# Paramètre : -oldApplicationHome
# Syntaxe : -oldApplicationHome <chemin répertoire>
# Description :
# 	Chemin d'accès complet au répertoire principal de l'application dans l'installation 2.x ou 3.0.x.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Il s'agit d'un paramètre obligatoire.
#  - <chemin répertoire> doit correspondre à un répertoire existant qui se termine par 'server/conf'.
#    Exemple : /Jazz/IBM/RRC_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Paramètre : -applicationContextRoot
# Syntaxe : -applicationContextRoot <racine>
# Description :
# 	Racine de contexte d'application du serveur 2.x ou 3.0.x.
# Valeur par défaut :
# 	rdm (2.x), rm (3.0.1)
# Contraintes :
#  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début).
#
APPLICATION_CONTEXT_ROOT=

# Paramètre : -oldJTSHome
# Syntaxe : -oldJTSHome <chemin répertoire>
# Description :
# 	Chemin d'accès complet au répertoire principal du serveur JTS dans l'installation 2.x ou 3.0.x.
# Valeur par défaut :
# 	<aucune>
# Remarque :
#     S'il est spécifié, cela signifie qu'une mise à niveau de la version 3.0 vers la
#     version 3.0.1 va avoir lieu pour RTC et JTS. Sinon, seul RTC est concerné, quel
#     que soit le type de mise à niveau détecté...
# Contraintes :
#  - <chemin répertoire> doit correspondre à un répertoire existant qui se termine par 'server/conf'.
#  - Valide uniquemement pour les mises à niveau de RM et de JTS.
#
OLD_JTS_HOME=

# Paramètre : -oldJTSContextRoot
# Syntaxe : -oldJTSContextRoot <racine>
# Description :
# 	Racine de contexte JTS du serveur 2.x ou 3.0.x
# Valeur par défaut :
# 	jazz
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RM.
#  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début).
#
OLD_JTS_CONTEXT_ROOT=jazz

# Paramètre : -updateTomcatFiles
# Syntaxe : -updateTomcatFiles <yes | no>
# Description :
# 	Indique si les fichiers de configuration Tomcat doivent être mis à jour.
# Valeur par défaut :
# 	yes
# Contraintes :
#  - Les seules valeurs admises sont 'yes' et 'no'.
#
UPDATE_TOMCAT_FILES=yes

# Paramètre : -oldApplicationTomcatHome
# Syntaxe : -oldApplicationTomcatHome <chemin répertoire>
# Description :
# 	Chemin d'accès complet au répertoire principal Tomcat de l'application dans l'installation 2.x ou 3.0.x.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RM.
#  - Doit correspondre à un répertoire existant
#
OLD_TOMCAT_HOME=

# Paramètre : -oldJTSTomcatHome
# Syntaxe : -oldJTSTomcatHome <chemin répertoire>
# Description :
# 	Chemin d'accès complet au répertoire principal Tomcat du serveur JTS dans l'installation 2.x ou 3.0.x.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RM.
#  - Doit correspondre à un répertoire existant
#
OLD_JTS_TOMCAT_HOME=

# Paramètre : -newApplicationHome
# Syntaxe : -newApplicationHome <chemin répertoire>
# Description :
# 	Chemin d'accès au répertoire principal de l'application dans l'installation 3.0.1.2.
# Valeur par défaut :
# 	conf
# Contraintes :
#  - Admis uniquement pour la mise à niveau de RTC, QM et RM.
#  - Lorsqu'il est admis, il s'agit d'un paramètre obligatoire.
#  - <chemin répertoire> doit correspondre à un répertoire existant qui se termine par 'server/conf'.
#    Exemple : /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Paramètre : -newJTSHome
# Syntaxe : -newJTSHome <chemin répertoire>
# Description :
# 	Chemin d'accès complet au répertoire principal du serveur JTS dans l'application 3.0.1.2.
# Valeur par défaut :
# 	Le répertoire principal de la nouvelle application
# Contraintes :
#  - <chemin répertoire> doit correspondre à un répertoire existant qui se termine par 'server/conf'.
#
NEW_JTS_HOME=

# Paramètre : -newJTSContextRoot
# Syntaxe : -newJTSContextRoot <racine>
# Description :
# 	Racine de contexte du serveur JTS 3.0.1.2.
# Valeur par défaut :
# 	jts
# Contraintes :
#  - <racine> doit correspondre à un nom unique de répertoire valide (sans barre oblique au début).
#
JTS_CONTEXT_ROOT=jts

# Paramètre : -newApplicationTomcatHome
# Syntaxe : -newApplicationTomcatHome <chemin répertoire>
# Description :
# 	Chemin d'accès au répertoire principal Tomcat de l'application dans l'installation 3.0.1.2.
# Valeur par défaut :
# 	<aucune>
#
NEW_TOMCAT_HOME=

# Paramètre : -newJTSTomcatHome
# Syntaxe : -newJTSTomcatHome <chemin répertoire>
# Description :
# 	Chemin d'accès au répertoire principal Tomcat du serveur JTS dans l'installation 3.0.1.2.
# Valeur par défaut :
# 	<aucune>
#
NEW_JTS_TOMCAT_HOME=

# Paramètre : -noPrompt
# Syntaxe : -noPrompt
# Description :
# 	Ne pas demander confirmation (toujours utiliser noPrompt) lors de l'exécution des commandes repotools.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Les seules valeurs admises sont la valeur vide et 'noPrompt'.
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Paramètre : -overwrite
# Syntaxe : -overwrite
# Description :
# 	Forcer le remplacement (toujours utiliser overwrite=yes) lors de l'exécution des commandes repotools.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Les seules valeurs admises sont la valeur vide et 'overwrite=yes'.
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Paramètre : -noVerify
# Syntaxe : -noVerify
# Description :
# 	Ne pas effectuer de vérification (toujours utiliser noVerify) lors de l'exécution des commandes repotools.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Les seules valeurs admises sont la valeur vide et 'noVerify'.
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Paramètre : -importFromFile
# Syntaxe : -importFromFile <chemin fichier>
# Description :
# 	Importer le contenu d'un fichier tar dans les tables de base de données.
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Le chemin doit désigner un fichier valide qui existe.
#
IMPORT_FROM_FILE=

# Paramètre : -noStepPrompt
# Syntaxe : -noStepPrompt
# Description :
# 	Ne pas demander confirmation avant chaque étape de mise à niveau.
# Valeur par défaut :
# 	false
# Contraintes :
#  - Les seules valeurs admises sont 'true' et 'false'.
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Paramètre : -jtsURL
# Syntaxe : -jtsURL <URI public JTS>
# Description :
# 	URI public du serveur JTS
# Valeur par défaut :
# 	<aucune>
# Contraintes :
#  - Accepté uniquement pour la mise à niveau de RM
#  - Requis uniquement dans un déploiement distribué où le serveur JTS est en cours d'exécution sur une autre instance de serveur que l'application RM
#
JTS_PUBLIC_URL=