#!/bin/sh
# *******************************************************************************
#  Materiale su licenza - Proprietà di IBM
#  (c) Copyright IBM Corporation 2006, 2011. Tutti i diritti riservati.
#
#  Nota relativa a limitazioni dei diritti per gli utenti del Governo degli Stati Uniti:
#  L'uso, la duplicazione o la divulgazione sono limitati dal GSA ADP Schedule
#  Contract con IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Definire le variabili d'ambiente corrispondenti ai
# # parametri di script rm_upgrade.sh e ai relativi valori predefiniti
# #
# #===========================================================
# #
# # Questo file viene letto all'inizio dell'esecuzione dello script
# # rm_upgrade.sh. Esso imposta una variabile di ambiente
# # per parametro valido con valore predefinito.
# #
# # Gli utenti possono modificare il valore predefinito per
# # avviare lo script rm_upgrade.sh con i propri valori
# # senza dover immettere il parametro e il corrispondente
# # valore manualmente sulla riga comandi.
# #
# # AVVERTENZA:
# # Non tutte le variabili devono essere impostate in base
# # all'applicazione correntemente aggiornata.  Leggere attentamente ogni commento
# # prima di modificare il valore.
# #
# #############################################################

# Parametro: -oldApplicationHome
# Uso: -oldApplicationHome <percorso dir>
# Descrizione:
# 	Percorso completo della directory home dell'applicazione nell'installazione 2.x o 3.0.x.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Questo è un parametro obbligatorio
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#    ad esempio, /Jazz/IBM/RRC_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Parametro: -applicationContextRoot
# Uso: -applicationContextRoot<root>
# Descrizione:
# 	La root di contesto dell'applicazione del server 2.x o 3.0.x.
# Valore predefinito:
# 	rdm (2.x), rm (3.0.1)
# Limitazioni:
#  - <root> deve essere una singola directory valida (senza barra iniziale)
#
APPLICATION_CONTEXT_ROOT=

# Parametro: -oldJTSHome
# Uso: -oldJTSHome <percorso dir>
# Descrizione:
# 	Il percorso completo della directory home JTS nell'installazione 2.x o 3.0.x.
# Valore predefinito:
# 	<nessun valore>
# Nota:
#     se specificato, significa che verrà eseguito un aggiornamento da 3.0 a 3.0.1
#     sia per RTC che per JTS. In caso contrario, qualsiasi sia il tipo di aggiornamento
#     rilevato, ne sarà interessato solo RTC...
# Limitazioni:
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#  - Valido solo per aggiornamenti RM e JTS
#
OLD_JTS_HOME=

# Parametro: -oldJTSContextRoot
# Uso: -oldJTSContextRoot <root>
# Descrizione:
# 	La root di contesto JTS del server 2.x o 3.0.x
# Valore predefinito:
# 	jazz
# Limitazioni:
#  - Accettato solo per un aggiornamento RM
#  - <root> deve essere una singola directory valida (senza barra iniziale)
#
OLD_JTS_CONTEXT_ROOT=jazz

# Parametro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descrizione:
# 	Indica se aggiornare i file di configurazione Tomcat.
# Valore predefinito:
# 	yes
# Limitazioni:
#  - Gli unici valori validi sono 'yes' e 'no'
#
UPDATE_TOMCAT_FILES=yes

# Parametro: -oldApplicationTomcatHome
# Uso: -oldApplicationTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso completo della directory root Tomcat dell'applicazione nell'installazione 2.x o 3.0.x.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Accettato solo per l'aggiornamento RM
#  - Deve essere una directory esistente
#
OLD_TOMCAT_HOME=

# Parametro: -oldJTSTomcatHome
# Uso: -oldJTSTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso completo della directory root Tomcat JTS nell'installazione 2.x o 3.0.x.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Accettato solo per l'aggiornamento RM
#  - Deve essere una directory esistente
#
OLD_JTS_TOMCAT_HOME=

# Parametro: -newApplicationHome
# Uso: -newApplicationHome <percorso dir>
# Descrizione:
# 	Il percorso della directory home dell'applicazione nell'istallazione 3.0.1.2.
# Valore predefinito:
# 	conf
# Limitazioni:
#  - Accettato solo per un aggiornamento RTC, QM e RM
#  - Se accettato, questo è un parametro obbligatorio
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#    ad esempio, /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parametro: -newJTSHome
# Uso: -newJTSHome <percorso dir>
# Descrizione:
# 	Percorso completo della directory home JTS nell'installazione 3.0.1.2.
# Valore predefinito:
# 	La nuova directory home dell'applicazione
# Limitazioni:
#  - <percorso dir> deve essere una directory esistente che termina con 'server/conf'
#
NEW_JTS_HOME=

# Parametro: -newJTSContextRoot
# Uso: -newJTSContextRoot <root>
# Descrizione:
# 	La root di contesto del server JTS 3.0.1.2.
# Valore predefinito:
# 	jts
# Limitazioni:
#  - <root> deve essere una singola directory valida (senza barra iniziale)
#
JTS_CONTEXT_ROOT=jts

# Parametro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso della directory root Tomcat dell'applicazione nell'installazione 3.0.1.2.
# Valore predefinito:
# 	<nessun valore>
#
NEW_TOMCAT_HOME=

# Parametro: -newJTSTomcatHome
# Uso: -newJTSTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso della directory root Tomcat JTS nell'installazione 3.0.1.2.
# Valore predefinito:
# 	<nessun valore>
#
NEW_JTS_TOMCAT_HOME=

# Parametro: -noPrompt
# Uso: -noPrompt
# Descrizione:
# 	Non richiede alcuna conferma (ad esempio, utilizza sempre noPrompt) durante l'esecuzione di un qualsiasi comando repotools
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Gli unici valori validi sono il valore vuoto o 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parametro: -overwrite
# Uso: -overwrite
# Descrizione:
# 	Forza la sovrascrittura (ad esempio, utilizza sempre overwrite=yes) durante l'esecuzione di qualsiasi comando repotools
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Gli unici valori validi sono il valore vuoto o 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parametro: -noVerify
# Uso: -noVerify
# Descrizione:
# 	Non esegue alcuna verifica (utilizza sempre noVerify) durante l'esecuzione dei comandi repotools
# Valore predefinito:
# 	<nessuno>
# Limitazioni:
#  - Gli unici valori validi sono il valore vuoto o 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parametro: -importFromFile
# Uso: -importFromFile <percorso file>
# Descrizione:
# 	Importa il contenuto di un file tar nelle tabelle di database
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Il percorso deve fare riferimento a un file esistente valido
#
IMPORT_FROM_FILE=

# Parametro: -noStepPrompt
# Uso: -noStepPrompt
# Descrizione:
# 	Non richiede prima di ogni passo di aggiornamento
# Valore predefinito:
# 	false
# Limitazioni:
#  - Gli unici valori validi sono 'true' e 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Parametro: -jtsURL
# Utilizzo: -jtsURL <JTS public URI>
# Descrizione:
# 	URI pubblica del JTS
# Valore predefinito:
# 	<nessuno>
# Vincoli:
#  - accettato solo nell'aggiornamento RM
#  - necessario solo in una distribuzione in cui JTS è in esecuzione su un'istanza server diversa da quella dell'applicazione RM
#
JTS_PUBLIC_URL=