#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2006, 2011. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # rm_upgrade.sh スクリプト・パラメーターとそのデフォルト
# # 値に対応する環境変数の定義
# #
# #===========================================================
# #
# # このファイルは、rm_upgrade.sh スクリプトの実行の開始時に
# # 読み取られます。これは、定義済みのデフォルト値がある
# # 有効なパラメーターごとに 1 つの環境変数を設定します。
# #
# # ユーザーは、デフォルト値を変更して rm_upgrade.sh スクリ
# # プトを独自の値で起動することもできます。そうすれば、コマン
# # ド行でパラメーターとそれに対応する値を手動で入力する必要
# # はありません。
# #
# # 警告:
# # すべてのアプリケーションにすべての変数を設定する必要は
# # ありません。値を変更する前に、それぞれのコメントを
# # 注意深くお読みください。
# #
# #############################################################

# パラメーター: -oldApplicationHome
# 使用法: -oldApplicationHome <ディレクトリー・パス>
# 説明:
# 	2.x または 3.0.x インストール済み環境でのアプリケーション・ホーム・ディレクトリーの絶対パス。
# デフォルト:
# 	<なし>
# 制約:
#  - これは必須パラメーターです。
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#    例: /Jazz/IBM/RRC_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# パラメーター: -applicationContextRoot
# 使用法: -applicationContextRoot<root>
# 説明:
# 	2.x または 3.0.x サーバーのアプリケーション・コンテキスト・ルート。
# デフォルト:
# 	rdm (2.x), rm (3.0.1)
# 制約:
#  - <ルート> は有効な単一のディレクトリー名 (前にスラッシュがないもの) でなければなりません。
#
APPLICATION_CONTEXT_ROOT=

# パラメーター: -oldJTSHome
# 使用法: -oldJTSHome <ディレクトリー・パス>
# 説明:
# 	2.x または 3.0.x インストール済み環境での JTS ホーム・ディレクトリーの絶対パス。
# デフォルト:
# 	<なし>
# 注:
#     これを指定した場合、RTC と JTS の両方で 3.0 から 3.0.1 へのアップ
#     グレードが行われることになります。 そうでない場合、どのような種類の
#     アップグレードが検出されても、関係するのは RTC のみです...
# 制約:
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#  - RM と JTS のアップグレードの場合にのみ有効です。
#
OLD_JTS_HOME=

# パラメーター: -oldJTSContextRoot
# 使用法: -oldJTSContextRoot <root>
# 説明:
# 	2.x または 3.0.x サーバーの JTS コンテキスト・ルート
# デフォルト:
# 	jazz
# 制約:
#  - RM アップグレードの場合のみ受け入れられます。
#  - <ルート> は有効な単一のディレクトリー名 (前にスラッシュがつかないもの) でなければなりません。
#
OLD_JTS_CONTEXT_ROOT=jazz

# パラメーター: -updateTomcatFiles
# 使用法: -updateTomcatFiles <yes | no>
# 説明:
# 	Tomcat 構成ファイルを更新するかどうか。
# デフォルト:
# 	yes
# 制約:
#  - 有効値は「yes」および「no」のみです。
#
UPDATE_TOMCAT_FILES=yes

# パラメーター: -oldApplicationTomcatHome
# 使用法: -oldApplicationTomcatHome <ディレクトリー・パス>
# 説明:
# 	2.x または 3.0.x インストール済み環境でのアプリケーション Tomcat ルート・ディレクトリーのパス。
# デフォルト:
# 	<なし>
# 制約:
#  - RM アップグレードの場合のみ受け入れられます。
#  - 既存のディレクトリーでなければなりません。
#
OLD_TOMCAT_HOME=

# パラメーター: -oldJTSTomcatHome
# 使用法: -oldJTSTomcatHome <ディレクトリー・パス>
# 説明:
# 	2.x または 3.0.x インストール済み環境での JTS Tomcat ルート・ディレクトリーのパス。
# デフォルト:
# 	<なし>
# 制約:
#  - RM アップグレードの場合のみ受け入れられます。
#  - 既存のディレクトリーでなければなりません。
#
OLD_JTS_TOMCAT_HOME=

# パラメーター: -newApplicationHome
# 使用法: -newApplicationHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールでのアプリケーション・ホーム・ディレクトリーのパス。
# デフォルト:
# 	conf
# 制約:
#  - RTC、QM、および RM アップグレードの場合のみ受け入れられます。
#  - 受け入れられた場合、これは必須パラメーターとなります。
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#    例: /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# パラメーター: -newJTSHome
# 使用法: -newJTSHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールでの JTS ホーム・ディレクトリーの絶対パス。
# デフォルト:
# 	新規のアプリケーション・ホーム・ディレクトリー
# 制約:
#  - <ディレクトリー・パス> は、「server/conf」で終わる既存のディレクトリーでなければなりません。
#
NEW_JTS_HOME=

# パラメーター: -newJTSContextRoot
# 使用法: -newJTSContextRoot <ルート>
# 説明:
# 	3.0.1.2 JTS サーバーのコンテキスト・ルート。
# デフォルト:
# 	jts
# 制約:
#  - <ルート> は有効な単一のディレクトリー名 (前にスラッシュがないもの) でなければなりません。
#
JTS_CONTEXT_ROOT=jts

# パラメーター: -newApplicationTomcatHome
# 使用法: -newApplicationTomcatHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールでのアプリケーション Tomcat ルート・ディレクトリーのパス。
# デフォルト:
# 	<なし>
#
NEW_TOMCAT_HOME=

# パラメーター: -newJTSTomcatHome
# 使用法: -newJTSTomcatHome <ディレクトリー・パス>
# 説明:
# 	3.0.1.2 インストールでの JTS Tomcat ルート・ディレクトリーのパス。
# デフォルト:
# 	<なし>
#
NEW_JTS_TOMCAT_HOME=

# パラメーター: -noPrompt
# 使用法: -noPrompt
# 説明:
# 	repotools コマンドの実行中に確認のプロンプトを出しません (つまり、常に noPrompt を使用)。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「noPrompt」のみです。
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# パラメーター: -overwrite
# 使用法: -overwrite
# 説明:
# 	repotools コマンドの実行中に強制的に上書きを行います (つまり、常に overwrite=yes を使用)。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「overwrite=yes」のみです。
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# パラメーター: -noVerify
# 使用法: -noVerify
# 説明:
# 	repotools コマンドの実行中に検査を実行しません (つまり、常に noVerify を使用)。
# デフォルト:
# 	<なし>
# 制約:
#  - 有効値は空または「noVerify」のみです。
#
# NO_VERIFY=noVerify
NO_VERIFY=

# パラメーター: -importFromFile
# 使用法: -importFromFile <file path>
# 説明:
# 	tar ファイルのコンテンツをデータベース表にインポートします。
# デフォルト:
# 	<なし>
# 制約:
#  - パスは、既存の有効なファイルを指している必要があります。
#
IMPORT_FROM_FILE=

# パラメーター: -noStepPrompt
# 使用法: -noStepPrompt
# 説明:
# 	各アップグレード・ステップの前にプロンプトを出しません。
# デフォルト:
# 	false
# 制約:
#  - 有効値は「true」または「false」のみです。
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# パラメーター: -jtsURL
# 使用法: -jtsURL <JTS public URI>
# 説明:
# 	JTS のパブリック URI
# デフォルト:
# 	<なし>
# 制約:
#  - RM アップグレードでのみ許容される
#  - JTS が RM アプリケーションとは別のサーバー・インスタンスで実行されている分散デプロイメントでのみ必要
#
JTS_PUBLIC_URL=