#!/bin/sh
# *******************************************************************************
#  Materiais Licenciados - Propriedade da IBM
#  (c) Copyright IBM Corporation 2006, 2011. Todos os Direitos Reservados.
#
#  Nota sobre Direitos Restritos para Usuários do Governo dos Estados Unidos:
#  Uso, duplicação ou divulgação restritos pelo documento GSA ADP Schedule Contract
#  com a IBM Corporation.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Definir as variáveis de ambiente correspondentes aos
# # parâmetros de rm_upgrade.sh e seus valores padrão
# #
# #===========================================================
# #
# # Este arquivo é lido no início da execução do script
# # rm_upgrade.sh. Ele configura uma variável de ambiente
# # por parâmetro válido com um valor padrão predefinido.
# #
# # Usuários podem desejar modificar o valor padrão para
# # ativar o script rm_upgrade.sh com seus próprios valores
# # se precisar inserir o parâmetro e seu
# # valor correspondente manualmente na linha de comandos.
# #
# # AVISO:
# # Nem todas as variáveis precisam ser configuradas para todo
# # aplicativo.  Leia cada comentário cuidadosamente antes de modificar
# # o valor.
# #
# #############################################################

# Parâmetro: -oldApplicationHome
# Uso: -oldApplicationHome <dir path>
# Descrição:
# 	Caminho completo para o diretório inicial do aplicativo na instalação 2.x ou 3.0.x.
# Padrão:
# 	<none>
# Restrições:
#  - este é um parâmetro obrigatório
#  - <dir path> deve ser um diretório existente terminado em 'server/conf'
#    ex.: /Jazz/IBM/RRC_2.x/jazz/server/conf
#
OLD_APPLICATION_HOME=

# Parâmetro: -applicationContextRoot
# Uso: -applicationContextRoot<root>
# Descrição:
# 	Raiz de contexto de aplicativos do servidor 2.x ou 3.0.x.
# Padrão:
# 	rdm (2.x), rm (3.0.1)
# Restrições:
#  - <root> deve ser um nome de diretório único válido (por exemplo, sem barra inicial)
#
APPLICATION_CONTEXT_ROOT=

# Parâmetro: -oldJTSHome
# Uso: -oldJTSHome <dir path>
# Descrição:
# 	Caminho completo para o diretório inicial de JTS na instalação 2.x ou 3.0.x.
# Padrão:
# 	<none>
# Nota:
#     Se especificado, significa que ocorrerá um upgrade de 3.0 para 3.0.1
#     para RTC e JTS. Caso contrário, qualquer que seja o tipo de upgrade
#     detectado, somente o RTC estará envolvido...
# Restrições:
#  - <dir path> deve ser um diretório existente terminado em 'server/conf'
#  - Válido somente para upgrades do RM e JTS
#
OLD_JTS_HOME=

# Parâmetro: -oldJTSContextRoot
# Uso: -oldJTSContextRoot <root>
# Descrição:
# 	Raiz de Contexto de JTS do servidor 2.x ou 3.0.x
# Padrão:
# 	jazz
# Restrições:
#  - Aceito apenas para upgrade do RM
#  - <root> deve ser um nome de diretório único válido (por exemplo, sem barra inicial)
#
OLD_JTS_CONTEXT_ROOT=jazz

# Parâmetro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descrição:
# 	Se os arquivos de configuração do tomcat serão atualizados.
# Padrão:
# 	yes
# Restrições:
#  - Os únicos valores válidos são 'yes' e 'no'
#
UPDATE_TOMCAT_FILES=yes

# Parâmetro: -oldApplicationTomcatHome
# Uso: -oldApplicationTomcatHome <dir path>
# Descrição:
# 	Caminho completo para o diretório-raiz do Tomcat do Aplicativo na instalação 2.x ou 3.0.x.
# Padrão:
# 	<none>
# Restrições:
#  - Aceito somente para o upgrade do RM
#  - Deve estar em um diretório existente
#
OLD_TOMCAT_HOME=

# Parâmetro: -oldJTSTomcatHome
# Uso: -oldJTSTomcatHome <dir path>
# Descrição:
# 	Caminho completo para o diretório-raiz do JTS Tomcat na instalação 2.x ou 3.0.x.
# Padrão:
# 	<none>
# Restrições:
#  - Aceito somente para upgrade do RM
#  - Deve estar em um diretório existente
#
OLD_JTS_TOMCAT_HOME=

# Parâmetro: -newApplicationHome
# Uso: -newApplicationHome <dir path>
# Descrição:
# 	Caminho para o diretório inicial do Aplicativo na instalação 3.0.1.2.
# Padrão:
# 	conf
# Restrições:
#  - Aceito somente para upgrade do RTC, QM e RM
#  - Quando aceito, este é um parâmetro obrigatório
#  - <dir path> deve estar em um diretório existente terminado em 'server/conf'
#    ex.: /Jazz/IBM/RRC_3.0/JazzTeamServer/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parâmetro: -newJTSHome
# Uso: -newJTSHome <dir path>
# Descrição:
# 	Caminho completo para o diretório inicial de JTS na instalação 3.0.1.2.
# Padrão:
# 	O novo diretório inicial do aplicativo
# Restrições:
#  - <dir path> deve estar em um diretório existente terminado em 'server/conf'
#
NEW_JTS_HOME=

# Parâmetro: -newJTSContextRoot
# Uso: -newJTSContextRoot <root>
# Descrição:
# 	Raiz de contexto do servidor JTS 3.0.1.2.
# Padrão:
# 	jts
# Restrições:
#  - <root> deve ser um nome de diretório único válido (por exemplo, sem barra inicial)
#
JTS_CONTEXT_ROOT=jts

# Parâmetro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <dir path>
# Descrição:
# 	Caminho para o diretório-raiz do Tomcat do Aplicativo na instalação 3.0.1.2.
# Padrão:
# 	<none>
#
NEW_TOMCAT_HOME=

# Parâmetro: -newJTSTomcatHome
# Uso: -newJTSTomcatHome <dir path>
# Descrição:
# 	Caminho para o diretório-raiz do JTS Tomcat na instalação 3.0.1.2.
# Padrão:
# 	<none>
#
NEW_JTS_TOMCAT_HOME=

# Parâmetro: -noPrompt
# Uso: -noPrompt
# Descrição:
# 	Não solicitar nenhuma confirmação (ex. usar sempre noPrompt) ao executar qualquer comando repotools
# Padrão:
# 	<none>
# Restrições:
#  - Os únicos valores válidos são vazio ou 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parâmetro: -overwrite
# Uso: -overwrite
# Descrição:
# 	Forçar a sobrescrição (ex. sempre usar overwrite=yes) ao executar qualquer comando repotools
# Padrão:
# 	<none>
# Restrições:
#  - Os únicos valores válidos são vazio ou 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parâmetro: -noVerify
# Uso: -noVerify
# Descrição:
# 	Não executar nenhuma verificação (ex. sempre usar noVerify) ao executar quaisquer comandos repotools                                                                                                    # Padrão: # 	<none>
# Padrão:
# 	<none>
# Restrições:
#  - Os únicos valores válidos são vazio ou 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parâmetro: -importFromFile
# Uso: -importFromFile <file path>
# Descrição:
# 	Importar o conteúdo de um arquivo tar em tabelas de banco de dados
# Padrão:
# 	<none>
# Restrições:
#  - O caminho deve apontar para um arquivo existente e válido
#
IMPORT_FROM_FILE=

# Parâmetro: -noStepPrompt
# Uso: -noStepPrompt
# Descrição:
# 	Não avisar antes de cada etapa de upgrade
# Padrão:
# 	false
# Restrições:
#  - Os únicos valores válidos são 'true' ou 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false

# Parâmetro: -jtsURL
# Uso: -jtsURL <JTS public URI>
# Descrição:
# 	URI Pública do JTS
# Padrão:
# 	<nenhum>
# Restrições:
#  - Aceito apenas para atualização de RM
#  - Necessário apenas em uma implementação distribuída onde o JTS está sendo executado em uma instância de servidor diferente do aplicativo RM
#
JTS_PUBLIC_URL=